@@ -21,6 +21,7 @@ module Data.FileEmbed
       embedFile
     , embedOneFileOf
     , embedDir
+    , embedDirListing
     , getDir
       -- * Embed as a IsString
     , embedStringFile
@@ -90,7 +91,7 @@ embedFile fp =
 -- > import qualified Data.ByteString
 -- >
 -- > myFile :: Data.ByteString.ByteString
--- > myFile = $(embedFile' [ "dirName/fileName", "src/dirName/fileName" ])
+-- > myFile = $(embedOneFileOf [ "dirName/fileName", "src/dirName/fileName" ])
 embedOneFileOf :: [FilePath] -> Q Exp
 embedOneFileOf ps =
   (runIO $ readExistingFile ps) >>= \ ( path, content ) -> do
@@ -118,6 +119,18 @@ embedDir fp = do
     e <- ListE <$> ((runIO $ fileList fp) >>= mapM (pairToExp fp))
     return $ SigE e typ
 
+-- | Embed a directory listing recursively in your source code.
+--
+-- > myFiles :: [FilePath]
+-- > myFiles = $(embedDirListing "dirName")
+--
+-- @since 0.0.11
+embedDirListing :: FilePath -> Q Exp
+embedDirListing fp = do
+    typ <- [t| [FilePath] |]
+    e <- ListE <$> ((runIO $ fmap fst <$> fileList fp) >>= mapM strToExp)
+    return $ SigE e typ
+
 -- | Get a directory tree in the IO monad.
 --
 -- This is the workhorse of 'embedDir'
